==> org.jresearch.commons.gwt.flexess-1.0.2.jar: org/jresearch/commons/gwt/flexess/client/model/PermissionModel.java <==
package org.jresearch.commons.gwt.flexess.client.model;

import java.util.List;

import org.jresearch.commons.gwt.client.model.DomainNewModel;

public class PermissionModel extends DomainNewModel<String> {

	private static final long serialVersionUID = -5705542024857825838L;

	private String permissionTemplateId;
	private List<ParameterModel> parameters;
	private String roleId;

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		final StringBuilder builder = new StringBuilder();
		builder.append("PermissionModel ["); //$NON-NLS-1$
		if (getPermissionTemplateId() != null) {
			builder.append("getPermissionTemplateId()=").append(getPermissionTemplateId()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		}
		if (getRoleId() != null) {
			builder.append("getRoleId()=").append(getRoleId()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		}
		if (getParameters() != null) {
			builder.append("getParameters()=").append(getParameters()); //$NON-NLS-1$
		}
		builder.append("]"); //$NON-NLS-1$
		return builder.toString();
	}

	/**
	 * @return the permissionTemplateId
	 */
	public String getPermissionTemplateId() {
		return permissionTemplateId;
	}

	/**
	 * @param permissionTemplateId
	 *            the permissionTemplateId to set
	 */
	public void setPermissionTemplateId(final String permissionTemplateId) {
		this.permissionTemplateId = permissionTemplateId;
	}

	/**
	 * @return the parameters
	 */
	public List<ParameterModel> getParameters() {
		return parameters;
	}

	/**
	 * @param parameters
	 *            the parameters to set
	 */
	public void setParameters(final List<ParameterModel> parameters) {
		this.parameters = parameters;
	}

	/**
	 * @return the roleId
	 */
	public String getRoleId() {
		return roleId;
	}

	/**
	 * @param roleId
	 *            the roleId to set
	 */
	public void setRoleId(final String roleId) {
		this.roleId = roleId;
	}

}

==> org.jresearch.commons.gwt.flexess-1.0.8.jar: org/jresearch/commons/gwt/flexess/client/model/PermissionModel.java <==
package org.jresearch.commons.gwt.flexess.client.model;

import java.util.List;

import org.jresearch.commons.gwt.shared.model.DomainNewModel;

public class PermissionModel extends DomainNewModel<String> {

	private static final long serialVersionUID = -5705542024857825838L;

	private String permissionTemplateId;
	private List<ParameterModel> parameters;
	private String roleId;

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		final StringBuilder builder = new StringBuilder();
		builder.append("PermissionModel ["); //$NON-NLS-1$
		if (getPermissionTemplateId() != null) {
			builder.append("getPermissionTemplateId()=").append(getPermissionTemplateId()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		}
		if (getRoleId() != null) {
			builder.append("getRoleId()=").append(getRoleId()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		}
		if (getParameters() != null) {
			builder.append("getParameters()=").append(getParameters()); //$NON-NLS-1$
		}
		builder.append("]"); //$NON-NLS-1$
		return builder.toString();
	}

	/**
	 * @return the permissionTemplateId
	 */
	public String getPermissionTemplateId() {
		return permissionTemplateId;
	}

	/**
	 * @param permissionTemplateId
	 *            the permissionTemplateId to set
	 */
	public void setPermissionTemplateId(final String permissionTemplateId) {
		this.permissionTemplateId = permissionTemplateId;
	}

	/**
	 * @return the parameters
	 */
	public List<ParameterModel> getParameters() {
		return parameters;
	}

	/**
	 * @param parameters
	 *            the parameters to set
	 */
	public void setParameters(final List<ParameterModel> parameters) {
		this.parameters = parameters;
	}

	/**
	 * @return the roleId
	 */
	public String getRoleId() {
		return roleId;
	}

	/**
	 * @param roleId
	 *            the roleId to set
	 */
	public void setRoleId(final String roleId) {
		this.roleId = roleId;
	}

}
